@@ -56,7 +56,7 @@ function(x, r=6378137, ...) {
 setMethod("perimeter", signature(x='matrix'), 
 function(x, r=6378137, ...) {
 	x <- x[,1:2]
-	if (all.equal(x[1,], x[nrow(x),])) {
+	if (isTRUE(all.equal(x[1,], x[nrow(x),]))) {
 		x <- x[-nrow(x), ]
 	}
 	y = rbind(x[-1,], x[1,])
